markuptools.MarkupInventory
===========================

.. abjad-lineage:: abjad.tools.markuptools.MarkupInventory.MarkupInventory

.. autoclass:: abjad.tools.markuptools.MarkupInventory.MarkupInventory

.. only:: html

   Attribute summary
   -----------------

   .. autosummary::

      ~abjad.tools.markuptools.MarkupInventory.MarkupInventory.append
      ~abjad.tools.markuptools.MarkupInventory.MarkupInventory.count
      ~abjad.tools.markuptools.MarkupInventory.MarkupInventory.extend
      ~abjad.tools.markuptools.MarkupInventory.MarkupInventory.index
      ~abjad.tools.markuptools.MarkupInventory.MarkupInventory.insert
      ~abjad.tools.markuptools.MarkupInventory.MarkupInventory.item_class
      ~abjad.tools.markuptools.MarkupInventory.MarkupInventory.items
      ~abjad.tools.markuptools.MarkupInventory.MarkupInventory.keep_sorted
      ~abjad.tools.markuptools.MarkupInventory.MarkupInventory.pop
      ~abjad.tools.markuptools.MarkupInventory.MarkupInventory.remove
      ~abjad.tools.markuptools.MarkupInventory.MarkupInventory.reverse
      ~abjad.tools.markuptools.MarkupInventory.MarkupInventory.sort
      ~abjad.tools.markuptools.MarkupInventory.MarkupInventory.__contains__
      ~abjad.tools.markuptools.MarkupInventory.MarkupInventory.__delitem__
      ~abjad.tools.markuptools.MarkupInventory.MarkupInventory.__eq__
      ~abjad.tools.markuptools.MarkupInventory.MarkupInventory.__format__
      ~abjad.tools.markuptools.MarkupInventory.MarkupInventory.__getitem__
      ~abjad.tools.markuptools.MarkupInventory.MarkupInventory.__hash__
      ~abjad.tools.markuptools.MarkupInventory.MarkupInventory.__iadd__
      ~abjad.tools.markuptools.MarkupInventory.MarkupInventory.__illustrate__
      ~abjad.tools.markuptools.MarkupInventory.MarkupInventory.__iter__
      ~abjad.tools.markuptools.MarkupInventory.MarkupInventory.__len__
      ~abjad.tools.markuptools.MarkupInventory.MarkupInventory.__ne__
      ~abjad.tools.markuptools.MarkupInventory.MarkupInventory.__repr__
      ~abjad.tools.markuptools.MarkupInventory.MarkupInventory.__reversed__
      ~abjad.tools.markuptools.MarkupInventory.MarkupInventory.__setitem__

Bases
-----

- :py:class:`datastructuretools.TypedList <abjad.tools.datastructuretools.TypedList.TypedList>`

- :py:class:`datastructuretools.TypedCollection <abjad.tools.datastructuretools.TypedCollection.TypedCollection>`

- :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject>`

- :py:class:`abctools.AbjadObject.AbstractBase <abjad.tools.abctools.AbjadObject.AbstractBase>`

- :py:class:`__builtin__.object <object>`

Read-only properties
--------------------

.. autoattribute:: abjad.tools.markuptools.MarkupInventory.MarkupInventory.item_class
   :noindex:

.. autoattribute:: abjad.tools.markuptools.MarkupInventory.MarkupInventory.items
   :noindex:

Read/write properties
---------------------

.. autoattribute:: abjad.tools.markuptools.MarkupInventory.MarkupInventory.keep_sorted
   :noindex:

Methods
-------

.. automethod:: abjad.tools.markuptools.MarkupInventory.MarkupInventory.append
   :noindex:

.. automethod:: abjad.tools.markuptools.MarkupInventory.MarkupInventory.count
   :noindex:

.. automethod:: abjad.tools.markuptools.MarkupInventory.MarkupInventory.extend
   :noindex:

.. automethod:: abjad.tools.markuptools.MarkupInventory.MarkupInventory.index
   :noindex:

.. automethod:: abjad.tools.markuptools.MarkupInventory.MarkupInventory.insert
   :noindex:

.. automethod:: abjad.tools.markuptools.MarkupInventory.MarkupInventory.pop
   :noindex:

.. automethod:: abjad.tools.markuptools.MarkupInventory.MarkupInventory.remove
   :noindex:

.. automethod:: abjad.tools.markuptools.MarkupInventory.MarkupInventory.reverse
   :noindex:

.. automethod:: abjad.tools.markuptools.MarkupInventory.MarkupInventory.sort
   :noindex:

Special methods
---------------

.. automethod:: abjad.tools.markuptools.MarkupInventory.MarkupInventory.__contains__
   :noindex:

.. automethod:: abjad.tools.markuptools.MarkupInventory.MarkupInventory.__delitem__
   :noindex:

.. automethod:: abjad.tools.markuptools.MarkupInventory.MarkupInventory.__eq__
   :noindex:

.. automethod:: abjad.tools.markuptools.MarkupInventory.MarkupInventory.__format__
   :noindex:

.. automethod:: abjad.tools.markuptools.MarkupInventory.MarkupInventory.__getitem__
   :noindex:

.. automethod:: abjad.tools.markuptools.MarkupInventory.MarkupInventory.__hash__
   :noindex:

.. automethod:: abjad.tools.markuptools.MarkupInventory.MarkupInventory.__iadd__
   :noindex:

.. automethod:: abjad.tools.markuptools.MarkupInventory.MarkupInventory.__illustrate__
   :noindex:

.. automethod:: abjad.tools.markuptools.MarkupInventory.MarkupInventory.__iter__
   :noindex:

.. automethod:: abjad.tools.markuptools.MarkupInventory.MarkupInventory.__len__
   :noindex:

.. automethod:: abjad.tools.markuptools.MarkupInventory.MarkupInventory.__ne__
   :noindex:

.. automethod:: abjad.tools.markuptools.MarkupInventory.MarkupInventory.__repr__
   :noindex:

.. automethod:: abjad.tools.markuptools.MarkupInventory.MarkupInventory.__reversed__
   :noindex:

.. automethod:: abjad.tools.markuptools.MarkupInventory.MarkupInventory.__setitem__
   :noindex:
